==> ejc-purchasingmanagement-impl-3.0.0-20220709.090003-146-sources.jar: com/ejianc/business/purchasingmanagement/bean/FreighttransferdetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购运费调账子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_freighttransferdetail")
public class FreighttransferdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 
    @TableField(value="bill_code")
    private String billCode; // 验收单编号
    @TableField(value="transporter_id")
    private Long transporterId; // 供应商主键
    @TableField(value="transporter_name")
    private String transporterName; // 供应商名称
    @TableField(value="material_id")
    private Long materialId; // 原材料主键（即采购合同子表主键）
    @TableField(value="material_name")
    private String materialName; // 原材料名称
    @TableField(value="acceptance_time")
    private String acceptanceTime; // 验收日期
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 含税金额
    @TableField(value="unpaid_money")
    private BigDecimal unpaidMoney; // 应付未付金额
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="adjusted_money")
    private BigDecimal adjustedMoney; // 调整后金额
    @TableField(value="materialacceptance_id")
    private Long materialacceptanceId; // 验收单主键
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getTransporterId() {
        return transporterId;
    }

    public void setTransporterId(Long transporterId) {
        this.transporterId = transporterId;
    }
    public String getTransporterName() {
        return transporterName;
    }

    public void setTransporterName(String transporterName) {
        this.transporterName = transporterName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getAcceptanceTime() {
        return acceptanceTime;
    }

    public void setAcceptanceTime(String acceptanceTime) {
        this.acceptanceTime = acceptanceTime;
    }
    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }
    public BigDecimal getUnpaidMoney() {
        return unpaidMoney;
    }

    public void setUnpaidMoney(BigDecimal unpaidMoney) {
        this.unpaidMoney = unpaidMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public BigDecimal getAdjustedMoney() {
        return adjustedMoney;
    }

    public void setAdjustedMoney(BigDecimal adjustedMoney) {
        this.adjustedMoney = adjustedMoney;
    }
    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220718.141214-167-sources.jar: com/ejianc/business/purchasingmanagement/bean/FreighttransferdetailEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购运费调账子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_freighttransferdetail")
public class FreighttransferdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 
    @TableField(value="bill_code")
    private String billCode; // 验收单编号
    @TableField(value="transporter_id")
    private Long transporterId; // 供应商主键
    @TableField(value="transporter_name")
    private String transporterName; // 供应商名称
    @TableField(value="material_id")
    private Long materialId; // 原材料主键（即采购合同子表主键）
    @TableField(value="material_name")
    private String materialName; // 原材料名称
    @TableField(value="acceptance_time")
    private Date acceptanceTime; // 验收日期
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 含税金额
    @TableField(value="unpaid_money")
    private BigDecimal unpaidMoney; // 应付未付金额
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="adjusted_money")
    private BigDecimal adjustedMoney; // 调整后金额
    @TableField(value="materialacceptance_id")
    private Long materialacceptanceId; // 验收单主键
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getTransporterId() {
        return transporterId;
    }

    public void setTransporterId(Long transporterId) {
        this.transporterId = transporterId;
    }
    public String getTransporterName() {
        return transporterName;
    }

    public void setTransporterName(String transporterName) {
        this.transporterName = transporterName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Date getAcceptanceTime() {
        return acceptanceTime;
    }

    public void setAcceptanceTime(Date acceptanceTime) {
        this.acceptanceTime = acceptanceTime;
    }
    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }
    public BigDecimal getUnpaidMoney() {
        return unpaidMoney;
    }

    public void setUnpaidMoney(BigDecimal unpaidMoney) {
        this.unpaidMoney = unpaidMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public BigDecimal getAdjustedMoney() {
        return adjustedMoney;
    }

    public void setAdjustedMoney(BigDecimal adjustedMoney) {
        this.adjustedMoney = adjustedMoney;
    }
    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}
